@@ -1,10 +1,21 @@
+/**
+ * Copyright (C) 2007-2012 Lawrence Murray
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the Free
+ * Software Foundation; either version 2 of the License, or (at your option)
+ * any later version.
+ * 
+ * @author Lawrence Murray <lawrence@indii.org>
+ * $Rev: 363 $
+ * $Date: 2012-01-22 18:45:43 +0800 (Sun, 22 Jan 2012) $
+ */
 #ifndef INDII_CLUSTER_EUCLIDEANDISTANCE_HPP
 #define INDII_CLUSTER_EUCLIDEANDISTANCE_HPP
 
 #include "ClusterVector.hpp"
 
 namespace indii {
-  namespace cluster {
 /**
  * Euclidean distance.
  *
@@ -25,11 +36,9 @@ public:
       const typename ClusterVector<T>::type& x2);
 
 };
-
-  }
 }
 
-T indii::cluster::EuclideanDistance::distance(
+T indii::EuclideanDistance::distance(
     const typename ClusterVector<T>::type& x1,
     const typename ClusterVector<T>::type& x2) {
   /* pre-condition */
