@@ -1,10 +1,21 @@
+/**
+ * Copyright (C) 2007-2012 Lawrence Murray
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the Free
+ * Software Foundation; either version 2 of the License, or (at your option)
+ * any later version.
+ * 
+ * @author Lawrence Murray <lawrence@indii.org>
+ * $Rev: 363 $
+ * $Date: 2012-01-22 18:45:43 +0800 (Sun, 22 Jan 2012) $
+ */
 #ifndef INDII_CLUSTER_PEARSONDISTANCE_HPP
 #define INDII_CLUSTER_PEARSONDISTANCE_HPP
 
 #include "ClusterVector.hpp"
 
 namespace indii {
-  namespace cluster {
 /**
  * Pearson distance.
  *
@@ -32,34 +43,40 @@ public:
       const typename ClusterVector<T>::type& x2);
 
 };
-
-  }
 }
 
 #include <cassert>
 
 template<class T>
-inline void indii::cluster::PearsonDistance<T>::prepare(
+inline void indii::PearsonDistance<T>::prepare(
     typename ClusterVector<T>::type& x) {
   /* pre-condition */
   assert (x.size() == ClusterVector<T>::N);
 
-  const unsigned int N = ClusterVector<T>::N;
-  T mu;
+  static const unsigned int N = ClusterVector<T>::N;
+  T mu, norm;
   
   mu = boost::numeric::ublas::sum(x) / N;
   x -= boost::numeric::ublas::scalar_vector<T>(N,mu);
-  x /= boost::numeric::ublas::norm_2(x);
+  norm = boost::numeric::ublas::norm_2(x);
+  if (norm > 0.0) {
+    x /= norm;
+  }
 }
 
 template<class T>
-inline T indii::cluster::PearsonDistance<T>::distance(
+inline T indii::PearsonDistance<T>::distance(
     const typename ClusterVector<T>::type& x1,
     const typename ClusterVector<T>::type& x2) {
   /* pre-condition */
   assert (x1.size() == x2.size());
 
-  return static_cast<T>(1.0) - boost::numeric::ublas::inner_prod(x1,x2);
+  T d = static_cast<T>(1.0) - boost::numeric::ublas::inner_prod(x1,x2);
+  
+  /* relaxed IEEE compliance, so make sure this is bound as expected */
+  //d = std::max((T)0.0, std::min(d, (T)2.0));
+  
+  return d;
 }
  
 #endif
