@@ -1,37 +1,48 @@
+/**
+ * Copyright (C) 2007-2012 Lawrence Murray
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the Free
+ * Software Foundation; either version 2 of the License, or (at your option)
+ * any later version.
+ * 
+ * @author Lawrence Murray <lawrence@indii.org>
+ * $Rev: 363 $
+ * $Date: 2012-01-22 18:45:43 +0800 (Sun, 22 Jan 2012) $
+ */
 #ifndef INDII_TINT_GUI_PREPROCESSPANE_HPP
 #define INDII_TINT_GUI_PREPROCESSPANE_HPP
 
-#include "TintPane.hpp"
-#include "../ClusterModel.hpp"
-#include "../ClusterModelObserver.hpp"
+#include "../model/ClusterModel.hpp"
+#include "../model/ClusterModelObserver.hpp"
+#include "../../gui/Pane.hpp"
 
 #include "wx/spinctrl.h"
 #include "wx/textctrl.h"
 
 namespace indii {
-  namespace tint {
-    namespace gui {
 /**
  * Preprocess settings pane.
- *
- * @author Lawrence Murray <lawrence@indii.org>
- * @version $Rev: 74 $
- * @date $Date: 2009-03-02 14:59:56 +0900 (Mon, 02 Mar 2009) $
  */
-class PreProcessPane : public TintPane, public ClusterModelObserver {
+class PreProcessPane : public Pane, public ClusterModelObserver {
 public:
   /**
    * Constructor.
    *
    * @param parent Parent.
-   * @param model Cluster model.
    */
-  PreProcessPane(wxWindow* parent, ClusterModel* model);
+  PreProcessPane(wxWindow* parent);
+
+  /**
+   * Set model.
+   *
+   * @param model Model.
+   */
+  void setModel(ClusterModel* model);  
 
   /*
    * Handle model changes.
    */
-  virtual void notifyNumClustersChange();
   virtual void notifyNumRepetitionsChange();
   virtual void notifyMaxPixelsChange();
   virtual void notifySaturationThresholdChange();
@@ -39,11 +50,15 @@ public:
   /*
    * Handle control events.
    */
-  void OnSpinK(wxSpinEvent& evt);
   void OnSpinReps(wxSpinEvent& evt);
   void OnSpinSat(wxSpinEvent& evt);
   void OnTextMaxPixels(wxCommandEvent& evt);
 
+  /**
+   * Context sensitive help.
+   */
+  void OnHelp(wxHelpEvent& evt);
+
 private:
   /**
    * Cluster model.
@@ -53,26 +68,20 @@ private:
   /*
    * Controls.
    */
-  wxSpinCtrl *spinK, *spinReps, *spinSat;
+  wxSpinCtrl *spinReps, *spinSat;
   wxTextCtrl *textMaxPixels;
 
   /*
    * Control ids.
    */
   enum ID {
-    ID_SPIN_K,
     ID_SPIN_REPS,
     ID_SPIN_SAT,
     ID_TEXT_MAX_PIXELS,
   };
 
   DECLARE_EVENT_TABLE()
-
 };
-
-    }
-  }
 }
 
 #endif
-
