@@ -1,22 +1,30 @@
+/**
+ * Copyright (C) 2007-2012 Lawrence Murray
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the Free
+ * Software Foundation; either version 2 of the License, or (at your option)
+ * any later version.
+ * 
+ * @author Lawrence Murray <lawrence@indii.org>
+ * $Rev: 363 $
+ * $Date: 2012-01-22 18:45:43 +0800 (Sun, 22 Jan 2012) $
+ */
 #ifndef INDII_TINT_GUI_THUMBHSL_HPP
 #define INDII_TINT_GUI_THUMBHSL_HPP
 
-#include "../ImageResource.hpp"
-#include "../ClusterModel.hpp"
-#include "../ClusterModelObserver.hpp"
+#include "ThumbImage.hpp"
+#include "SpectrumImage.hpp"
+#include "../../image/ImageResource.hpp"
+#include "../model/ClusterModel.hpp"
+#include "../model/ClusterModelObserver.hpp"
 
 #include "wx/panel.h"
 #include "wx/slider.h"
 
 namespace indii {
-  namespace tint {
-    namespace gui {
 /**
  * Thumbnail with Hue-Saturation-Luminance sliders.
- *
- * @author Lawrence Murray <lawrence@indii.org>
- * @version $Rev: 92 $
- * @date $Date: 2009-08-02 17:56:45 +0800 (Sun, 02 Aug 2009) $
  */
 class ThumbHSL : public wxPanel, public ClusterModelObserver {
 public:
@@ -24,28 +32,28 @@ public:
    * Constructor.
    *
    * @param parent Parent window.
-   * @param res Image resource manager. Caller retains ownership.
-   * @param model Cluster model. Caller retains ownership.
    * @param cluster Cluster number to which this thumbnail pertains.
    */
-  ThumbHSL(wxWindow *parent, ImageResource* res, ClusterModel* model,
-      const unsigned int cluster);
+  ThumbHSL(wxWindow *parent, const unsigned int cluster);
 
   /**
-   * Destructor.
+   * Set model.
+   *
+   * @param model Model.
    */
-  ~ThumbHSL();
+  void setModel(ClusterModel* model);
 
   /*
    * Handle model changes.
    */
   virtual void notifyNumClustersChange();
   virtual void notifySaturationDecayChange();
-  virtual void notifyCentroidDecayChange();
   virtual void notifySaturationSoftnessChange();
-  virtual void notifyCentroidSoftnessChange();
   virtual void notifyClusterChange(const unsigned int i);  
-
+  virtual void notifyHueChange(const unsigned i);
+  virtual void notifySatChange(const unsigned i);
+  virtual void notifyLightChange(const unsigned i);
+  
   /*
    * Slider control events.
    */
@@ -54,11 +62,6 @@ public:
   void OnSlideL(wxScrollEvent& evt);
 
 private:
-  /**
-   * Image resource manager.
-   */
-  ImageResource* res;
-
   /**
    * Cluster model.
    */
@@ -70,10 +73,12 @@ private:
   unsigned int cluster;
 
   /*
-   * Sliders.
+   * Controls.
    */
   wxSlider *slideH, *slideS, *slideL;
-
+  SpectrumImage *spectH, *spectS, *spectL;
+  ThumbImage* thumb;
+  
   /*
    * Slider control ids.
    */
@@ -83,13 +88,18 @@ private:
     ID_SLIDE_L
   };
 
+	/**
+   * Exponent for nonlinear saturation slider behaviour.
+   */
+	static const float SPOW;
+
+	/**
+   * Exponent for nonlinear saturation slider behaviour.
+   */
+	static const float LPOW;
+  
   DECLARE_EVENT_TABLE()
-
 };
-
-    }
-  }
 }
 
 #endif
-
