@@ -1,6 +1,18 @@
+/**
+ * Copyright (C) 2007-2012 Lawrence Murray
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the Free
+ * Software Foundation; either version 2 of the License, or (at your option)
+ * any later version.
+ * 
+ * @author Lawrence Murray <lawrence@indii.org>
+ * $Rev: 364 $
+ * $Date: 2012-01-22 20:27:14 +0800 (Sun, 22 Jan 2012) $
+ */
 #include "ThumbImage.hpp"
 
-#include "../ImageManipulation.hpp"
+#include "../../image/ImageManipulation.hpp"
 
 #include "wx/dcmemory.h"
 #include "wx/dcbuffer.h"
@@ -8,27 +20,30 @@
 #define ICON_SIZE 100
 #define THUMB_SIZE 80
 
-using namespace indii::tint;
-using namespace indii::tint::gui;
+using namespace indii;
 
-ThumbImage::ThumbImage(wxWindow *parent,
-    ImageResource* res, ClusterModel* model, const unsigned int cluster) :
+ThumbImage::ThumbImage(wxWindow *parent, const unsigned int cluster) :
     wxControl(parent, -1, wxDefaultPosition, wxDefaultSize, wxBORDER_NONE),
-    res(res), model(model), cluster(cluster),
-    isActive(cluster < model->getNumClusters() && model->isShown(cluster)),
-	fg(ICON_SIZE,ICON_SIZE), bg(ICON_SIZE,ICON_SIZE) {
-  watch(model);
-
+    model(NULL), cluster(cluster), isActive(false), isOver(false),
+    fg(ICON_SIZE,ICON_SIZE), bg(ICON_SIZE,ICON_SIZE) {
   SetBackgroundStyle(wxBG_STYLE_CUSTOM);
   SetSize(ICON_SIZE,ICON_SIZE);
   SetMinSize(wxSize(ICON_SIZE,ICON_SIZE));
 
-  prepareBackground();
   fgPrepared = false;
 }
 
-ThumbImage::~ThumbImage() {
-  //
+void ThumbImage::setModel(ClusterModel* model) {
+  this->model = model;
+  ignore();
+
+  if (model != NULL) {
+    watch(model);
+    prepareBackground();
+    notifyNumClustersChange();
+    notifySaturationDecayChange();
+    notifySaturationSoftnessChange();
+  }
 }
 
 void ThumbImage::notifyNumClustersChange() {
@@ -46,13 +61,6 @@ void ThumbImage::notifySaturationDecayChange() {
   }
 }
 
-void ThumbImage::notifyCentroidDecayChange() {
-  if (cluster < model->getNumClusters()) {
-    fgPrepared = false;
-    Refresh();
-  }
-}
-
 void ThumbImage::notifySaturationSoftnessChange() {
   if (cluster < model->getNumClusters()) {
     fgPrepared = false;
@@ -60,35 +68,50 @@ void ThumbImage::notifySaturationSoftnessChange() {
   }
 }
 
-void ThumbImage::notifyCentroidSoftnessChange() {
-  if (cluster < model->getNumClusters()) {
-    fgPrepared = false;
-    Refresh();
-  }
-}
-
 void ThumbImage::notifyClusterChange(const unsigned int i) {
   //
 }
 
+void ThumbImage::notifySatChange(const unsigned int i) {
+  /* pre-condition */
+  assert (model != NULL);
+
+  if (cluster == i && model->isShown(cluster) != isActive) {
+    isActive = model->isShown(cluster);
+    Refresh();
+  }
+}
+
 void ThumbImage::OnPaint(wxPaintEvent& evt) {
+  /* pre-condition */
+  assert (model != NULL);
+
   if (cluster < model->getNumClusters()) {
     if (!fgPrepared) {
       prepareForeground();
     }
 
     int x, y;
-    x = (ICON_SIZE - THUMB_SIZE) / 2 + 1;
-    y = (ICON_SIZE - THUMB_SIZE) / 2 + 1;
+    x = (ICON_SIZE - THUMB_SIZE) / 2;
+    y = (ICON_SIZE - THUMB_SIZE) / 2;
 
-	wxPaintDC dc(this);
-	dc.SetBackground(wxBrush(wxColour(69,69,69)));
-	dc.Clear();
+    wxPaintDC dc(this);
+    #ifndef WX_28
+    dc.Clear();
+    #endif
     if (isActive) {
-      dc.SetBrush(wxBrush(wxColour(128,128,128)));
+      dc.SetBrush(wxBrush(*wxWHITE));
       dc.SetPen(wxPen(model->getColour(cluster), 3));
-      dc.DrawRoundedRectangle(2, 2, ICON_SIZE - 4, ICON_SIZE - 4, 10);
+    } else if (isOver) {
+      dc.SetBrush(wxBrush(*wxWHITE));
+      dc.SetPen(wxPen(wxColor(128,128,128), 2));      
+    } else {
+      dc.SetBrush(wxBrush(*wxWHITE));
+      dc.SetPen(wxPen(wxColor(128,128,128), 1));
     }
+      
+    dc.DrawRoundedRectangle(2, 2, ICON_SIZE - 4, ICON_SIZE - 4, 10);
+    
     dc.DrawBitmap(bg, x, y);
     dc.DrawBitmap(fg, x, y);
   }
@@ -101,24 +124,31 @@ void ThumbImage::OnLeftDown(wxMouseEvent& evt) {
 }
 
 void ThumbImage::OnLeftUp(wxMouseEvent& evt) {
+  /* pre-condition */
+  assert (model != NULL);
+
   isActive = !model->isShown(cluster);
   Refresh();
   Update();
   model->show(cluster, isActive);
 }
 
+void ThumbImage::OnEnter(wxMouseEvent& evt) {
+  isOver = true;  
+  Refresh();
+}
+
 void ThumbImage::OnLeave(wxMouseEvent& evt) {
-  if (cluster < model->getNumClusters()) {
-    bool isShown = model->isShown(cluster);
-    if (isActive != isShown) {
-      isActive = isShown;  
-      Refresh();
-    }
-  }
+  isOver = false;  
+  Refresh();
 }
 
 void ThumbImage::prepareBackground() {
+  /* pre-condition */
+  assert (model != NULL);
+
   int thumbWidth, thumbHeight;
+  ImageResource* res = model->getImageResource();
 
   /* sizes, dimensions */
   res->fitOutside(THUMB_SIZE, THUMB_SIZE, &thumbWidth, &thumbHeight);
@@ -139,6 +169,10 @@ void ThumbImage::prepareBackground() {
 }
 
 void ThumbImage::prepareForeground() {
+  /* pre-condition */
+  assert (model != NULL);
+
+  ImageResource* res = model->getImageResource();
   int thumbWidth, thumbHeight;
 
   /* sizes, dimensions */
@@ -199,6 +233,6 @@ BEGIN_EVENT_TABLE(ThumbImage, wxWindow)
 EVT_PAINT(ThumbImage::OnPaint)
 //EVT_LEFT_DOWN(ThumbImage::OnLeftDown)
 EVT_LEFT_UP(ThumbImage::OnLeftUp)
-//EVT_LEAVE_WINDOW(ThumbImage::OnLeave)
+EVT_ENTER_WINDOW(ThumbImage::OnEnter)
+EVT_LEAVE_WINDOW(ThumbImage::OnLeave)
 END_EVENT_TABLE()
-
